from setuptools import setup

setup(
    name='renat',
    version='0.1',
    author='frozix',
    author_email='tolibaevrinat4@gmail.com',
    description='Математический модуль',
    py_modules=['renat'],
)